# Jupiter: An Integrated Environment for Automated Negotiators.
Jupiter is a negotiation environment that implements an open architecture for automated negotiators.
It provides a testbed for negotiating agents like Genius.
Genius is a previous work about negotiation environment.
If you have used Genius, it is easy for you to use Jupiter.
But this version has not been adequate to use Jupiter as an alternative to Genius yet.
Jupiter is under development now.

The feature is the following:
- is developed in Python3
- easy for agent developer to use machine learning library
- is able to use agents developed in Genius.


## Important links
- Homepage: under constructions
- User Guide: https://github.com/TomoyaFukui/Jupiter/blob/master/userguide.pdf
- Source code: https://github.com/TomoyaFukui/Jupiter
- Python package: https://pypi.python.org/pypi/jupiter-negotiation
- HTML documentation: https://github.com/TomoyaFukui/Jupiter/blob/master/docs/_build/html/index.html
- Paper: under writing
- Related research: http://ii.tudelft.nl/genius/

## Installation in Python
Jupiter is on PyPI, so you can use pip to install it:
```
# bash
$ pip install jupiter-negotiation
```
Jupiter is only developed in Python3.

## How to use
Please see https://github.com/TomoyaFukui/Jupiter/blob/master/notebooks/quick_start.ipynb
I will make GUI and CUI in the future.

## Changelog
### Version 0.0.dev5(2018.02.07)
- release jupiter-negotiation 0.0.dev5
- change directory structure
### Version 0.0.dev4(2018.01.15)
- release jupiter-negotiation 0.0.dev4
